==> cscec5b-wzxt-api-3.0.0-20210730.071650-289-sources.jar: com/ejianc/business/wzxt/vo/Purchase.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;


public class Purchase {
    // 订货单主键
    private String pkPurchase;
    // 组织主键   传来源组织主键
    private String pkOrg;
    // 项目主键    传来源项目主键
    private String pkProject;
    // 项目名称
    private String projectName;
    // 订货单编码
    private String purchaseCode;
    // 供应商主键     传来源供应商主键
    private String pkSupplier;
    // 供应商名称
    private String supplierName;
    // 采购合同主键
    private String pkContractPurchase;
    // 采购合同名称
    private String contractPurchaseName;
    // 采购合同编码
    private String contractPurchaseCode;
    // 订货单创建时间 yyyy-MM-dd
    private String purchaseCreateDate;
    // 订货单要求送货时间 yyyy-MM-dd
    private String purchaseExpiryDate;
    // 订货单联系人
    private String purchaseLinkMan;
    // 订货单联系电话
    private String purchaseLinkTelephone;
    // 订货单状态  传1  代表“待确认”
    private Integer billStatus;
    // 送货要求
    private String purchaseNote;
    // 送货地址
    private String purchaseAddress;
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
//    private String pkModified;//最后修改人
//    private String modifiedDate;//最后修改时间
    //使用部位
    private String planBody;
    //智能称重标识 0 激活 1 关闭
    private Integer smartStatus;
    //磅点类型 0、请选择   1、实达、 2、沣悦
    private String platformType;
    //磅点编号
    private String platformCode;
    // 订货单明细集合
    private List<PurchaseInfo> purchaseInfoList;
    //系统标识，广东公司为"gd";河南公司为"hn"
    private String sysmark;

    private Integer purchaseType;//0-材料采购订单 1-周转材租赁订单

    private java.lang.Integer isConfirm; // 是否供方确认单价（0-否1-是）

    public Integer getIsConfirm() {
        return isConfirm;
    }

    public void setIsConfirm(Integer isConfirm) {
        this.isConfirm = isConfirm;
    }

    public Integer getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(Integer purchaseType) {
        this.purchaseType = purchaseType;
    }

    public String getPkPurchase() {
        return pkPurchase;
    }

    public void setPkPurchase(String pkPurchase) {
        this.pkPurchase = pkPurchase;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPurchaseCode() {
        return purchaseCode;
    }

    public void setPurchaseCode(String purchaseCode) {
        this.purchaseCode = purchaseCode;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }

    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }

    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }

    public String getPurchaseCreateDate() {
        return purchaseCreateDate;
    }

    public void setPurchaseCreateDate(String purchaseCreateDate) {
        this.purchaseCreateDate = purchaseCreateDate;
    }

    public String getPurchaseExpiryDate() {
        return purchaseExpiryDate;
    }

    public void setPurchaseExpiryDate(String purchaseExpiryDate) {
        this.purchaseExpiryDate = purchaseExpiryDate;
    }

    public String getPurchaseLinkMan() {
        return purchaseLinkMan;
    }

    public void setPurchaseLinkMan(String purchaseLinkMan) {
        this.purchaseLinkMan = purchaseLinkMan;
    }

    public String getPurchaseLinkTelephone() {
        return purchaseLinkTelephone;
    }

    public void setPurchaseLinkTelephone(String purchaseLinkTelephone) {
        this.purchaseLinkTelephone = purchaseLinkTelephone;
    }

    public Integer getBillStatus() {
        return billStatus;
    }

    public void setBillStatus(Integer billStatus) {
        this.billStatus = billStatus;
    }

    public String getPurchaseNote() {
        return purchaseNote;
    }

    public void setPurchaseNote(String purchaseNote) {
        this.purchaseNote = purchaseNote;
    }

    public String getPurchaseAddress() {
        return purchaseAddress;
    }

    public void setPurchaseAddress(String purchaseAddress) {
        this.purchaseAddress = purchaseAddress;
    }

    public String getPlanBody() {
        return planBody;
    }

    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }

    public Integer getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(Integer smartStatus) {
        this.smartStatus = smartStatus;
    }

    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }

    public String getPlatformCode() {
        return platformCode;
    }

    public void setPlatformCode(String platformCode) {
        this.platformCode = platformCode;
    }

    public List<PurchaseInfo> getPurchaseInfoList() {
        return purchaseInfoList;
    }

    public void setPurchaseInfoList(List<PurchaseInfo> purchaseInfoList) {
        this.purchaseInfoList = purchaseInfoList;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }
}

==> cscec5b-wzxt-api-3.0.0-20210803.024704-292-sources.jar: com/ejianc/business/wzxt/vo/Purchase.java <==
package com.ejianc.business.wzxt.vo;

import java.util.List;


public class Purchase {
    // 订货单主键
    private String pkPurchase;
    // 组织主键   传来源组织主键
    private String pkOrg;
    // 项目主键    传来源项目主键
    private String pkProject;
    // 项目名称
    private String projectName;
    // 订货单编码
    private String purchaseCode;
    // 供应商主键     传来源供应商主键
    private String pkSupplier;
    // 供应商名称
    private String supplierName;
    // 采购合同主键
    private String pkContractPurchase;
    // 采购合同名称
    private String contractPurchaseName;
    // 采购合同编码
    private String contractPurchaseCode;
    // 订货单创建时间 yyyy-MM-dd
    private String purchaseCreateDate;
    // 订货单要求送货时间 yyyy-MM-dd
    private String purchaseExpiryDate;
    // 订货单联系人
    private String purchaseLinkMan;
    // 订货单联系电话
    private String purchaseLinkTelephone;
    // 订货单状态  传1  代表“待确认”
    private Integer billStatus;
    // 送货要求
    private String purchaseNote;
    // 送货地址
    private String purchaseAddress;
    private String pkCreator;
    private String creatorName;
    private String creatorDate;
//    private String pkModified;//最后修改人
//    private String modifiedDate;//最后修改时间
    //使用部位
    private String planBody;
    //智能称重标识 0 激活 1 关闭
    private Integer smartStatus;
    //磅点类型 0、请选择   1、实达、 2、沣悦
    private String platformType;
    //磅点编号
    private String platformCode;
    // 订货单明细集合
    private List<PurchaseInfo> purchaseInfoList;
    //系统标识，广东公司为"gd";河南公司为"hn"
    private String sysmark;

    private Integer purchaseType;//0-材料采购订单 1-周转材租赁订单

    private java.lang.Integer isConfirm; // 是否供方确认单价（0-否1-是）

    private List<FileRelation> orderfileList;//附件信息

    public List<FileRelation> getOrderfileList() {
        return orderfileList;
    }

    public void setOrderfileList(List<FileRelation> orderfileList) {
        this.orderfileList = orderfileList;
    }

    public Integer getIsConfirm() {
        return isConfirm;
    }

    public void setIsConfirm(Integer isConfirm) {
        this.isConfirm = isConfirm;
    }

    public Integer getPurchaseType() {
        return purchaseType;
    }

    public void setPurchaseType(Integer purchaseType) {
        this.purchaseType = purchaseType;
    }

    public String getPkPurchase() {
        return pkPurchase;
    }

    public void setPkPurchase(String pkPurchase) {
        this.pkPurchase = pkPurchase;
    }

    public String getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(String pkOrg) {
        this.pkOrg = pkOrg;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getPurchaseCode() {
        return purchaseCode;
    }

    public void setPurchaseCode(String purchaseCode) {
        this.purchaseCode = purchaseCode;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public String getPkContractPurchase() {
        return pkContractPurchase;
    }

    public void setPkContractPurchase(String pkContractPurchase) {
        this.pkContractPurchase = pkContractPurchase;
    }

    public String getContractPurchaseName() {
        return contractPurchaseName;
    }

    public void setContractPurchaseName(String contractPurchaseName) {
        this.contractPurchaseName = contractPurchaseName;
    }

    public String getContractPurchaseCode() {
        return contractPurchaseCode;
    }

    public void setContractPurchaseCode(String contractPurchaseCode) {
        this.contractPurchaseCode = contractPurchaseCode;
    }

    public String getPurchaseCreateDate() {
        return purchaseCreateDate;
    }

    public void setPurchaseCreateDate(String purchaseCreateDate) {
        this.purchaseCreateDate = purchaseCreateDate;
    }

    public String getPurchaseExpiryDate() {
        return purchaseExpiryDate;
    }

    public void setPurchaseExpiryDate(String purchaseExpiryDate) {
        this.purchaseExpiryDate = purchaseExpiryDate;
    }

    public String getPurchaseLinkMan() {
        return purchaseLinkMan;
    }

    public void setPurchaseLinkMan(String purchaseLinkMan) {
        this.purchaseLinkMan = purchaseLinkMan;
    }

    public String getPurchaseLinkTelephone() {
        return purchaseLinkTelephone;
    }

    public void setPurchaseLinkTelephone(String purchaseLinkTelephone) {
        this.purchaseLinkTelephone = purchaseLinkTelephone;
    }

    public Integer getBillStatus() {
        return billStatus;
    }

    public void setBillStatus(Integer billStatus) {
        this.billStatus = billStatus;
    }

    public String getPurchaseNote() {
        return purchaseNote;
    }

    public void setPurchaseNote(String purchaseNote) {
        this.purchaseNote = purchaseNote;
    }

    public String getPurchaseAddress() {
        return purchaseAddress;
    }

    public void setPurchaseAddress(String purchaseAddress) {
        this.purchaseAddress = purchaseAddress;
    }

    public String getPlanBody() {
        return planBody;
    }

    public void setPlanBody(String planBody) {
        this.planBody = planBody;
    }

    public Integer getSmartStatus() {
        return smartStatus;
    }

    public void setSmartStatus(Integer smartStatus) {
        this.smartStatus = smartStatus;
    }

    public String getPlatformType() {
        return platformType;
    }

    public void setPlatformType(String platformType) {
        this.platformType = platformType;
    }

    public String getPlatformCode() {
        return platformCode;
    }

    public void setPlatformCode(String platformCode) {
        this.platformCode = platformCode;
    }

    public List<PurchaseInfo> getPurchaseInfoList() {
        return purchaseInfoList;
    }

    public void setPurchaseInfoList(List<PurchaseInfo> purchaseInfoList) {
        this.purchaseInfoList = purchaseInfoList;
    }

    public String getSysmark() {
        return sysmark;
    }

    public void setSysmark(String sysmark) {
        this.sysmark = sysmark;
    }

    public String getPkCreator() {
        return pkCreator;
    }

    public void setPkCreator(String pkCreator) {
        this.pkCreator = pkCreator;
    }

    public String getCreatorName() {
        return creatorName;
    }

    public void setCreatorName(String creatorName) {
        this.creatorName = creatorName;
    }

    public String getCreatorDate() {
        return creatorDate;
    }

    public void setCreatorDate(String creatorDate) {
        this.creatorDate = creatorDate;
    }
}
